@@ -159,9 +159,9 @@ def getInstalledVideo(prefix="/"):
     return [x[:-7] for x in listDirectory(x11Drivers) if x.endswith('_drv.so')]
 
 
-def getDistfilesVideo(self, prefix="/"):
+def getDistfilesVideo(prefix="/"):
     """Get video drivers from distfiles"""
-    if os.path.isdir(path.join(self.Get('cl_chroot_path'), 'var/db/repos/gentoo')):
+    if os.path.isdir(path.join(prefix, 'var/db/repos/gentoo')):
         distFiles = path.join(prefix, "var/calculate/distfiles")
     else:
         distFiles = path.join(prefix, "usr/portage/distfiles")    
