@@ -36,7 +36,7 @@ class Locale():
         ('be_BY', {
             'name': 'Беларуский (Беларусь)',
             'layoutname': 'Беларуская',
-            'locale': 'be_BY.utf8',
+            'locale': 'be_BY.UTF-8',
             'keymap': 'by',
             'timezone': 'Europe/Minsk',
             'dumpkeys_charset': 'koi8-u',
@@ -47,7 +47,7 @@ class Locale():
         ('bg_BG', {
             'name': 'Български (България)',
             'layoutname': 'Български',
-            'locale': 'bg_BG.utf8',
+            'locale': 'bg_BG.UTF-8',
             'keymap': 'bg_bds-utf8',
             'dumpkeys_charset': '',
             'timezone': 'Europe/Sofia',
@@ -58,7 +58,7 @@ class Locale():
         ('bs_BA', {
             'name': 'Bosanski (Bosna i Hercegovina)',
             'layoutname': 'Bosanski',
-            'locale': 'bs_BA.utf8',
+            'locale': 'bs_BA.UTF-8',
             'keymap': 'slovene',
             'timezone': 'Europe/Sarajevo',
             'dumpkeys_charset': '',
@@ -69,7 +69,7 @@ class Locale():
         ('cs_CZ', {
             'name': 'Čeština (Česká republika)',
             'layoutname': 'Čeština',
-            'locale': 'cs_CZ.utf8',
+            'locale': 'cs_CZ.UTF-8',
             'keymap': 'cz',
             'timezone': 'Europe/Prague',
             'dumpkeys_charset': '',
@@ -80,7 +80,7 @@ class Locale():
         ('da_DK', {
             'name': 'Dansk (Danmark)',
             'layoutname': 'Dansk',
-            'locale': 'da_DK.utf8',
+            'locale': 'da_DK.UTF-8',
             'keymap': 'dk-latin1',
             'timezone': 'Europe/Copenhagen',
             'dumpkeys_charset': '',
@@ -91,7 +91,7 @@ class Locale():
         ('de_DE', {
             'name': 'Deutsch (Deutschland)',
             'layoutname': 'Deutsch',
-            'locale': 'de_DE.utf8',
+            'locale': 'de_DE.UTF-8',
             'keymap': 'de-latin1',
             'timezone': 'Europe/Berlin',
             'dumpkeys_charset': '',
@@ -102,7 +102,7 @@ class Locale():
         ('el_GR', {
             'name': 'Ελληνικά (Ελλάδα)',
             'layoutname': 'Greek',
-            'locale': 'el_GR.utf8',
+            'locale': 'el_GR.UTF-8',
             'keymap': 'gr',
             'timezone': 'Europe/Athens',
             'dumpkeys_charset': '',
@@ -113,7 +113,7 @@ class Locale():
         ('en_AU', {
             'name': 'English (Australia)',
             'layoutname': 'English',
-            'locale': 'en_AU.utf8',
+            'locale': 'en_AU.UTF-8',
             'keymap': 'us',
             'timezone': 'Australia/Canberra',
             'dumpkeys_charset': '',
@@ -124,7 +124,7 @@ class Locale():
         ('en_GB', {
             'name': 'English (United Kingdom)',
             'layoutname': 'United Kingdom',
-            'locale': 'en_GB.utf8',
+            'locale': 'en_GB.UTF-8',
             'keymap': 'uk',
             'timezone': 'Europe/London',
             'dumpkeys_charset': '',
@@ -135,7 +135,7 @@ class Locale():
         ('en_US', {
             'name': 'English (United States)',
             'layoutname': 'English',
-            'locale': 'en_US.utf8',
+            'locale': 'en_US.UTF-8',
             'keymap': 'us',
             'timezone': 'America/New_York',
             'dumpkeys_charset': '',
@@ -146,7 +146,7 @@ class Locale():
         ('es_ES', {
             'name': 'Español (España)',
             'layoutname': 'Español',
-            'locale': 'es_ES.utf8',
+            'locale': 'es_ES.UTF-8',
             'keymap': 'es euro2',
             'timezone': 'Europe/Madrid',
             'dumpkeys_charset': '',
@@ -157,7 +157,7 @@ class Locale():
         ('es_UY', {
             'name': 'Español (Uruguay)',
             'layoutname': 'Latin American',
-            'locale': 'es_UY.utf8',
+            'locale': 'es_UY.UTF-8',
             'keymap': 'la-latin1',
             'timezone': 'America/Montevideo',
             'dumpkeys_charset': '',
@@ -168,7 +168,7 @@ class Locale():
         ('es_VE', {
             'name': 'Español (Venezuela)',
             'layoutname': 'Latin American',
-            'locale': 'es_VE.utf8',
+            'locale': 'es_VE.UTF-8',
             'keymap': 'la-latin1',
             'timezone': 'America/Caracas',
             'dumpkeys_charset': '',
@@ -179,7 +179,7 @@ class Locale():
         ('et_EE', {
             'name': 'Eesti (Eesti)',
             'layoutname': 'Eesti',
-            'locale': 'et_EE.utf8',
+            'locale': 'et_EE.UTF-8',
             'keymap': 'et',
             'timezone': 'Europe/Tallinn',
             'dumpkeys_charset': '',
@@ -190,7 +190,7 @@ class Locale():
         ('fr_BE', {
             'name': 'Français (Belgique)',
             'layoutname': 'Belgique',
-            'locale': 'fr_BE.utf8',
+            'locale': 'fr_BE.UTF-8',
             'keymap': 'be-latin1',
             'timezone': 'Europe/Brussels',
             'dumpkeys_charset': '',
@@ -201,7 +201,7 @@ class Locale():
         ('fr_CA', {
             'name': 'Français (Canada)',
             'layoutname': 'French-Canadian',
-            'locale': 'fr_CA.utf8',
+            'locale': 'fr_CA.UTF-8',
             'keymap': 'cf',
             'timezone': 'Canada/Pacific',
             'dumpkeys_charset': '',
@@ -212,7 +212,7 @@ class Locale():
         ('fr_FR', {
             'name': 'Français (France)',
             'layoutname': 'Français',
-            'locale': 'fr_FR.utf8',
+            'locale': 'fr_FR.UTF-8',
             'keymap': 'fr-latin9',
             'timezone': 'Europe/Paris',
             'dumpkeys_charset': '',
@@ -223,7 +223,7 @@ class Locale():
         ('hr_HR', {
             'name': 'Hrvatski (Hrvatska)',
             'layoutname': 'Hrvatski',
-            'locale': 'hr_HR.utf8',
+            'locale': 'hr_HR.UTF-8',
             'keymap': 'croat',
             'timezone': 'Europe/Zagreb',
             'dumpkeys_charset': '',
@@ -234,7 +234,7 @@ class Locale():
         ('is_IS', {
             'name': 'Íslenska (Ísland)',
             'layoutname': 'Íslenska',
-            'locale': 'is_IS.utf8',
+            'locale': 'is_IS.UTF-8',
             'keymap': 'is-latin1',
             'timezone': 'Atlantic/Reykjavik',
             'dumpkeys_charset': '',
@@ -245,7 +245,7 @@ class Locale():
         ('it_IT', {
             'name': 'Italiano (Italia)',
             'layoutname': 'Italiano',
-            'locale': 'it_IT.utf8',
+            'locale': 'it_IT.UTF-8',
             'keymap': 'it',
             'dumpkeys_charset': '',
             'timezone': 'Europe/Rome',
@@ -256,7 +256,7 @@ class Locale():
         ('kk_KZ', {
             'name': 'Қазақ тілі (Қазақстан)',
             'layoutname': 'Қазақ тілі',
-            'locale': 'kk_KZ.utf8',
+            'locale': 'kk_KZ.UTF-8',
             'keymap': 'kaz_gost-unicode',
             'timezone': 'Asia/Almaty',
             'dumpkeys_charset': '',
@@ -267,7 +267,7 @@ class Locale():
         ('lt_LT', {
             'name': 'Lietuvių (Lietuva)',
             'layoutname': 'Lietuvių',
-            'locale': 'lt_LT.utf8',
+            'locale': 'lt_LT.UTF-8',
             'keymap': 'lt.baltic',
             'timezone': 'Europe/Vilnius',
             'dumpkeys_charset': '',
@@ -278,7 +278,7 @@ class Locale():
         ('lv_LV', {
             'name': 'Latviešu (Latvija)',
             'layoutname': 'Latviešu',
-            'locale': 'lv_LV.utf8',
+            'locale': 'lv_LV.UTF-8',
             'keymap': 'lv',
             'timezone': 'Europe/Riga',
             'dumpkeys_charset': '',
@@ -289,7 +289,7 @@ class Locale():
         ('hu_HU', {
             'name': 'Magyar (Magyarország)',
             'layoutname': 'Magyar',
-            'locale': 'hu_HU.utf8',
+            'locale': 'hu_HU.UTF-8',
             'keymap': 'hu',
             'timezone': 'Europe/Budapest',
             'dumpkeys_charset': '',
@@ -300,7 +300,7 @@ class Locale():
         ('nl_BE', {
             'name': 'Nederlands (België)',
             'layoutname': 'Dutch',
-            'locale': 'nl_BE.utf8',
+            'locale': 'nl_BE.UTF-8',
             'keymap': 'nl',
             'timezone': 'Europe/Brussels',
             'dumpkeys_charset': '',
@@ -311,7 +311,7 @@ class Locale():
         ('nl_NL', {
             'name': 'Nederlands (Nederland)',
             'layoutname': 'Dutch',
-            'locale': 'nl_NL.utf8',
+            'locale': 'nl_NL.UTF-8',
             'keymap': 'nl',
             'timezone': 'Europe/Amsterdam',
             'dumpkeys_charset': '',
@@ -322,7 +322,7 @@ class Locale():
         ('nb_NO', {
             'name': 'Norsk bokmål (Noreg)',
             'layoutname': 'Nynorsk',
-            'locale': 'nb_NO.utf8',
+            'locale': 'nb_NO.UTF-8',
             'keymap': 'no-latin1',
             'timezone': 'Europe/Oslo',
             'dumpkeys_charset': '',
@@ -333,7 +333,7 @@ class Locale():
         ('nn_NO', {
             'name': 'Norsk nynorsk (Noreg)',
             'layoutname': 'Nynorsk',
-            'locale': 'nn_NO.utf8',
+            'locale': 'nn_NO.UTF-8',
             'keymap': 'no-latin1',
             'timezone': 'Europe/Oslo',
             'dumpkeys_charset': '',
@@ -344,7 +344,7 @@ class Locale():
         ('pl_PL', {
             'name': 'Polski (Polska)',
             'layoutname': 'Polski',
-            'locale': 'pl_PL.utf8',
+            'locale': 'pl_PL.UTF-8',
             'keymap': 'pl',
             'timezone': 'Europe/Warsaw',
             'dumpkeys_charset': '',
@@ -355,7 +355,7 @@ class Locale():
         ('pt_BR', {
             'name': 'Português (Brasil)',
             'layoutname': 'Brasil',
-            'locale': 'pt_BR.utf8',
+            'locale': 'pt_BR.UTF-8',
             'keymap': 'br-abnt2',
             'timezone': 'Brazil/East',
             'dumpkeys_charset': '',
@@ -366,7 +366,7 @@ class Locale():
         ('pt_PT', {
             'name': 'Português (Portugal)',
             'layoutname': 'Português',
-            'locale': 'pt_PT.utf8@euro',
+            'locale': 'pt_PT.UTF-8@euro',
             'keymap': 'pt-latin9',
             'dumpkeys_charset': '',
             'timezone': 'Europe/Lisbon',
@@ -377,7 +377,7 @@ class Locale():
         ('ro_RO', {
             'name': 'Română (România)',
             'layoutname': 'Română',
-            'locale': 'ro_RO.utf8',
+            'locale': 'ro_RO.UTF-8',
             'keymap': 'ro_win',
             'timezone': 'Europe/Bucharest',
             'dumpkeys_charset': '',
@@ -388,7 +388,7 @@ class Locale():
         ('ru_RU', {
             'name': 'Русский (Россия)',
             'layoutname': 'Русская',
-            'locale': 'ru_RU.utf8',
+            'locale': 'ru_RU.UTF-8',
             'keymap': '-u ruwin_cplk-UTF-8',
             'timezone': 'Europe/Moscow',
             'dumpkeys_charset': '',
@@ -399,7 +399,7 @@ class Locale():
         ('sk_SK', {
             'name': 'Slovenčina (Slovenská republika)',
             'layoutname': 'Slovenčina',
-            'locale': 'sk_SK.utf8',
+            'locale': 'sk_SK.UTF-8',
             'keymap': 'sk-qwertz',
             'dumpkeys_charset': '',
             'timezone': 'Europe/Bratislava',
@@ -410,7 +410,7 @@ class Locale():
         ('sl_SI', {
             'name': 'Slovenščina (Slovenija)',
             'layoutname': 'Slovenščina',
-            'locale': 'sl_SI.utf8',
+            'locale': 'sl_SI.UTF-8',
             'keymap': 'slovene',
             'timezone': 'Europe/Ljubljana',
             'dumpkeys_charset': '',
@@ -421,7 +421,7 @@ class Locale():
         ('sq_AL', {
             'name': 'Shqip (Shqipëria)',
             'layoutname': 'Shqip',
-            'locale': 'sq_AL.utf8',
+            'locale': 'sq_AL.UTF-8',
             'keymap': 'al',
             'timezone': 'Europe/Tirane',
             'dumpkeys_charset': '',
@@ -432,7 +432,7 @@ class Locale():
         ('sr_RS', {
             'name': 'Српски (Србија)',
             'layoutname': 'Српски',
-            'locale': 'sr_RS.utf8',
+            'locale': 'sr_RS.UTF-8',
             'keymap': 'sr-unicode',
             'timezone': 'Europe/Belgrade',
             'dumpkeys_charset': '',
@@ -443,7 +443,7 @@ class Locale():
         ('fi_FI', {
             'name': 'Suomi (Suomi)',
             'layoutname': 'Suomi',
-            'locale': 'fi_FI.utf8',
+            'locale': 'fi_FI.UTF-8',
             'keymap': 'fi',
             'timezone': 'Europe/Helsinki',
             'dumpkeys_charset': '',
@@ -454,7 +454,7 @@ class Locale():
         ('sv_SE', {
             'name': 'Svenska (Sverige)',
             'layoutname': 'Svenska',
-            'locale': 'sv_SE.utf8',
+            'locale': 'sv_SE.UTF-8',
             'keymap': 'sv-latin1',
             'timezone': 'Europe/Stockholm',
             'dumpkeys_charset': '',
@@ -465,7 +465,7 @@ class Locale():
         ('uk_UA', {
             'name': 'Українська (Україна)',
             'layoutname': 'Українська',
-            'locale': 'uk_UA.utf8',
+            'locale': 'uk_UA.UTF-8',
             'keymap': 'ua-utf',
             'timezone': 'Europe/Kiev',
             'dumpkeys_charset': 'koi8-u',
